import parasail
from unittest import TestCase, main, expectedFailure


class Tests(TestCase):

    def test1(self):
        p = parasail.ssw_init("asdf", parasail.blosum62, 1)
        r = parasail.ssw_profile(p, "asdf", 10, 1)

        print(p.s1)
        print(p.s1Len)
        print(r.cigarLen)
        print(r.cigar[0])

        r = parasail.sw_trace("asdf", "asdf", 10, 1, parasail.blosum62)
        c = r.cigar
        print(c.len)
        print(c.seq[0])
        print(c.decode)

        p = parasail.profile_create_8("asdf", parasail.blosum62)
        r = parasail.sw_trace_striped_profile_8(p, "asdf", 10, 1)
        c = r.cigar
        print(c.len)
        print(c.seq[0])

        r = parasail.sw_trace("asdf", "asdf", 10, 1, parasail.blosum62)
        print(r.query)
        print(r.ref)


if __name__ == '__main__':
    main()



import ctypes
import platform
import os
import re
import sys

import numpy

__version__ = "1.3.3"
__title__ = "parasail"
__description__ = "pairwise sequence alignment library"
__uri__ = "https://github.com/jeffdaily/parasail-python"
__author__ = "Jeff Daily"
__email__ = "jeffrey.daily@gmail.com"
__license__ = "BSD"
__copyright__ = "Copyright (c) 2016 Jeff Daily"

# we need the parasail library loaded so we can query the version

_libname = "libparasail.so"
if platform.system() == 'Darwin':
    _libname = "libparasail.dylib"
elif platform.system() == 'Windows':
    _libname = "parasail.dll"
_libpath = os.path.join(os.path.dirname(__file__), _libname)
_includepath = os.path.join(os.path.dirname(__file__), "include")

_verbose = os.environ.get("PARASAIL_VERBOSE", False)

# attempt to load library from package location
_lib = None
try:
    _lib = ctypes.CDLL(_libpath)
except:
    if _verbose: print("failed to open '{}' in package location".format(_libname))

if not _lib:
    try:
        _lib = ctypes.CDLL(_libname)
    except:
        if _verbose: print("failed to open '{}' using ctypes.CDLL defaults".format(_libname))

def _lib_search():
    global _lib
    global _libpath
    _libpath = None
    for env_var in ["PARASAIL_LIBPATH", "LD_LIBRARY_PATH", "DYLD_LIBRARY_PATH", "PATH"]:
        if env_var in os.environ:
            if _verbose: print("searching {} for {}".format(env_var,_libname))
            for path in re.split("[:;]", os.environ[env_var]):
                if _verbose: print("searching {}".format(path))
                for attempt in [os.path.join(root,_libname) for root,dirs,files in os.walk(path) if _libname in files]:
                    try:
                        _lib = ctypes.CDLL(attempt)
                        _libpath = attempt
                        # shortcut the search during bindings import
                        os.environ["PARASAIL_LIBPATH"] = os.path.dirname(attempt)
                        if _verbose: print("found '{}'".format(attempt))
                        return
                    except:
                        if _verbose: print("attempted but failed to load '{}'".format(attempt))
        else:
            if _verbose: print("env var {} not set".format(env_var))

# if library load failed, search for it
if not _lib:
    _lib_search()

# library load still failed, hard error
if not _lib:
    raise Exception("failed to locate and open '{}'".format(_libname))

c_int_p = ctypes.POINTER(ctypes.c_int)

_lib.parasail_version.argtypes = [c_int_p, c_int_p, c_int_p]
_lib.parasail_version.restype = None

def version():
    major = ctypes.c_int()
    minor = ctypes.c_int()
    patch = ctypes.c_int()
    _lib.parasail_version(
            ctypes.byref(major),
            ctypes.byref(minor),
            ctypes.byref(patch))
    return major.value, minor.value, patch.value

major,minor,patch = version()

# now that we know the version, import the correct bindings
if major == 1:
    from parasail.bindings_v1 import *
else:
    from parasail.bindings_v2 import *

def get_include():
    """ Returns the path of the Parasail C library include files.
    """
    return _includepath

def get_library():
    """ Returns the path of the Parasail C library shared object file.
    """
    return _libpath



import parasail
from unittest import TestCase, main


class Tests(TestCase):

    def test1(self):
        matrix = parasail.blosum62
        matrix[3, 4] = 100
        print(matrix.matrix)

        matrix = parasail.blosum62.copy()
        matrix[3, 4] = 100
        print(matrix.matrix)

        matrix = parasail.matrix_create("ACGT", 10, 1)
        matrix[2] = 200
        matrix[1:3,  1:3] = 300
        matrix.set_value(0, 4, 400)
        print(matrix.matrix)

        matrix = parasail.matrix_create("AcgT", 10, 1)
        print(matrix.matrix)
        print(matrix.mapper)

        matrix = parasail.matrix_create("AcgT", 10, 1, True)
        print(matrix.matrix)
        print(matrix.mapper)


if __name__ == '__main__':
    main()



import parasail
from unittest import TestCase, main


class Tests(TestCase):

    def test1(self):
        result = parasail.sw("asdf", "asdf", 10, 1, parasail.blosum62)
        self.assertEqual(result.score, 20)

    def test2(self):
        result = parasail.sw("asdf", "asdf", 10, 1, parasail.pam50)
        self.assertEqual(result.score, 27)

    def test3(self):
        matrix = parasail.matrix_create("acgt", 1, -1)
        result = parasail.sw("acgt", "acgt", 10, 1, matrix)
        self.assertEqual(result.score, 4)

    def test4(self):
        profile = parasail.profile_create_8("asdf", parasail.blosum62)
        result = parasail.sw_striped_profile_8(profile, "asdf", 10, 1)
        self.assertEqual(result.score, 20)


if __name__ == '__main__':
    main()



import parasail
from unittest import TestCase,  main


class Tests(TestCase):

    def test(self):
        result = parasail.sw_table("asdf", "asdfasdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        with self.assertRaises(AttributeError):
            print(result.matches)
        with self.assertRaises(AttributeError):
            print(result.similar)
        with self.assertRaises(AttributeError):
            print(result.length)
        print(result.score_table)

        result = parasail.sw_stats_table("asdf", "asdfasdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        print(result.matches)
        print(result.similar)
        print(result.length)
        print(result.score_table)
        print(result.matches_table)
        print(result.similar_table)
        print(result.length_table)

        result = parasail.sw_rowcol("asdf", "asdfasdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        with self.assertRaises(AttributeError):
            print(result.matches)
        with self.assertRaises(AttributeError):
            print(result.similar)
        with self.assertRaises(AttributeError):
            print(result.length)
        print(result.score_row)
        print(result.score_col)

        result = parasail.sw_stats_rowcol("asdf", "asdfasdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        print(result.matches)
        print(result.similar)
        print(result.length)
        print(result.score_row)
        print(result.score_col)
        print(result.matches_row)
        print(result.matches_col)
        print(result.similar_row)
        print(result.similar_col)
        print(result.length_row)
        print(result.length_col)

        result = parasail.sw("asdf", "asdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        with self.assertRaises(AttributeError):
            print(result.matches)
        with self.assertRaises(AttributeError):
            print(result.similar)
        with self.assertRaises(AttributeError):
            print(result.length)
        with self.assertRaises(AttributeError):
            print(result.score_table)

        result = parasail.sw_stats("asdf", "asdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        print(result.matches)
        print(result.similar)
        print(result.length)

        result = parasail.sw_scan_32("asdf", "asdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        with self.assertRaises(AttributeError):
            print(result.matches)
        with self.assertRaises(AttributeError):
            print(result.similar)
        with self.assertRaises(AttributeError):
            print(result.length)

        result = parasail.sw_scan_16("asdf", "asdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        with self.assertRaises(AttributeError):
            print(result.matches)
        with self.assertRaises(AttributeError):
            print(result.similar)
        with self.assertRaises(AttributeError):
            print(result.length)

        result = parasail.sw_stats_striped_16("asdf", "asdf", 10, 1, parasail.blosum62)
        print(result)
        print(result.saturated)
        print(result.score)
        print(result.matches)
        print(result.similar)
        print(result.length)

        print(parasail.blosum62.name)
        print(parasail.blosum62.size)
        print(parasail.blosum62.matrix)

        profile = parasail.profile_create_8("asdf",  parasail.blosum62)
        profile = parasail.profile_create_8("asdf",  parasail.blosum62)
        print(profile)
        print(profile.s1)
        print(profile.matrix)

        result = parasail.sw_striped_profile_8(profile, "asdf", 10, 1)
        print(result)
        print(result.saturated)
        print(result.score)

        profile = parasail.profile_create_sat("asdf",  parasail.blosum62)
        print(profile)
        print(profile.s1)
        print(profile.matrix)
        print(dir(profile.matrix))
        print(profile.matrix.min)
        print(profile.matrix.max)
        print(profile.matrix.size)

        result = parasail.sw_striped_profile_sat(profile, "asdf", 10, 1)
        print(result)
        print(result.saturated)
        print(result.score)
        print(type(result.score))


if __name__ == '__main__':
    main()
